//File Description: Keep track of hot key actions

//Different States (All lists contain a _LENGTH enumeration at the end to store their length)
enum StatusState {STATUS_KEEP=0, STATUS_AVAILABLE, STATUS_AWAY, STATUS_DND, STATUS_INVISIBLE, STATUS_OFFLINE, STATUS_LENGTH}; //Status States
enum SetStatusMessageState {SSMS_KEEP=0, SSMS_STATIC, SSMS_LAST, SSMS_POPUP, SMSS_POPUP_LAST, SMSS_LENGTH}; //Set Status Message States
enum OtherHotKey {OHK_FOCUS=0, OHK_HIDE, OHK_BOTTOM, OHK_TASKBAR_VISIBILITY, OHK_SHOW_PENDING_CONVERSATION, OHK_LENGTH}; //Other Hot Keys
enum OtherOption {OO_TASKBAR_STARTUP=0, OO_LENGTH}; //Other Options

//Hotkey state information
enum ModifierKeys {MODK_CONTROL=1, MODK_ALT=2, MODK_SHIFT=4, MODK_WIN=8}; //Bit set for Modifier Keys
typedef struct _HotKey //A key that triggers an action
{
	guint16 Key; //The hardware_keycode
	unsigned char Modifiers; //Combination of "ModifierKey"s
} HotKey;
typedef struct _HotKeyAction_Info //Set Status Action
{
	enum StatusState State; //Can also take an "OtherHotKey Action" ... darn C not having anonymous unions :-\... When this is an OtherHotKey, MessageState and Message are unused (more anonymouse union problems...)
	enum SetStatusMessageState MessageState;
	char *Message; //Whenever allocated, use g_free to delete.
} HotKeyAction_Info;
enum HotKeyActionType { HKACTIONTYPE_SetStatus=0, HKACTIONTYPE_Other }; //The type of action
typedef struct _HotKeyAction //A full hotkey action
{
	HotKey Key;
	gboolean LocalOnly;
	enum HotKeyActionType Type;
	HotKeyAction_Info Info;
	int Identifier; //Used to identify the hotkey (This is platform/run independent and not saved to preferences)
} HotKeyAction;

//The list of actions
extern GList *Actions;

//Functions
void SaveAction(HotKeyAction *Action, gboolean SaveToPreferences); //Saves a Hotkey action
void DeleteAction(int ActionNumber, gboolean RemoveFromPreferences); //Deletes a Hotkey action
HotKeyAction* LoadActionFromPref(int ActionNumber); //Load an action's information from preferences
const HotKeyAction* GetDefaultSettings(int *NumSettings); //Returns the default settings, and the number of them into NumSettings
